pub fn formatted_float<F: Float + Display>(f: F, dec: usize) -> StringExpand description
Converts a float type to a String, rounds it and trims trailing zeros. The sign is displayed only for negative values. See formatted_float_signed.
dec: The number of decimals to use when rounding the number.